@@ -10,7 +10,7 @@ use strict;
 use warnings;
 our ( %Config, $VERSION );
 
-$VERSION = "5.040001";
+$VERSION = "5.040002";
 
 # Skip @Config::EXPORT because it only contains %Config, which we special
 # case below as it's not a function. @Config::EXPORT won't change in the
@@ -56,11 +56,11 @@ sub import {
     return;
 }
 
-die "$0: Perl lib version (5.40.1) doesn't match executable '$^X' version ($])"
+die "$0: Perl lib version (5.40.2) doesn't match executable '$^X' version ($])"
     unless $^V;
 
-$^V eq 5.40.1
-    or die sprintf "%s: Perl lib version (5.40.1) doesn't match executable '$^X' version (%vd)", $0, $^V;
+$^V eq 5.40.2
+    or die sprintf "%s: Perl lib version (5.40.2) doesn't match executable '$^X' version (%vd)", $0, $^V;
 
 
 sub FETCH {
@@ -86,7 +86,7 @@ sub AUTOLOAD {
 tie %Config, 'Config', {
     archlibexp => '/usr/lib/perl5/5.40/mipsel-linux',
     archname => 'mipsel-linux',
-    cc => 'mipsel-softfloat-linux-gnu-gcc',
+    cc => 'mipsel-unknown-linux-musl-gcc',
     d_readlink => 'define',
     d_symlink => 'define',
     dlext => 'so',
@@ -98,7 +98,7 @@ tie %Config, 'Config', {
     ldlibpthname => 'LD_LIBRARY_PATH',
     libpth => '/usr/lib',
     osname => 'linux',
-    osvers => '6.6.74-gentoo-dist',
+    osvers => '6.12.16-gentoo-dist',
     path_sep => ':',
     privlibexp => '/usr/lib/perl5/5.40',
     scriptdir => '/usr/bin',
@@ -107,5 +107,5 @@ tie %Config, 'Config', {
     so => 'so',
     useithreads => undef,
     usevendorprefix => 'define',
-    version => '5.40.1',
+    version => '5.40.2',
 };
