@@ -86,7 +86,7 @@ sub AUTOLOAD {
 tie %Config, 'Config', {
     archlibexp => '/usr/lib64/perl5/5.40/x86_64-linux',
     archname => 'x86_64-linux',
-    cc => 'x86_64-pc-linux-gnu-gcc',
+    cc => 'clang',
     d_readlink => 'define',
     d_symlink => 'define',
     dlext => 'so',
@@ -96,7 +96,7 @@ tie %Config, 'Config', {
     inc_version_list => ' ',
     intsize => '4',
     ldlibpthname => 'LD_LIBRARY_PATH',
-    libpth => '/usr/local/lib64 /lib64 /usr/lib64 /usr/lib',
+    libpth => '/usr/local/lib64 /lib64 /usr/lib64 /usr/lib/clang/19/lib /usr/lib',
     osname => 'linux',
     osvers => '6.12.17-serv',
     path_sep => ':',
